@@ -21,6 +21,7 @@ from wandb.internal import datastore
 
 from . import internal_api
 from . import file_stream
+from . import update
 
 from .file_pusher import FilePusher
 
@@ -118,7 +119,9 @@ class _SendManager(object):
         # is anyone using run_id?
         self._run_id = None
         self._api = internal_api.Api(default_settings=settings)
-        self._api_settings = {k: v for k, v in six.iteritems(dict(settings)) if k in ('project',) and v is not None}
+        api_keys = ('project', 'group', 'job_type',)
+        api_map = dict(run_id='name', run_name='display_name')
+        self._api_settings = {api_map.get(k, k): v for k, v in six.iteritems(dict(settings)) if (k in api_map or k in api_keys) and v is not None}
 
         # TODO(jhr): do something better, why do we need to send full lines?
         self._partial_output = dict()
@@ -373,6 +376,9 @@ def wandb_internal(settings, notify_queue, process_queue, req_queue, resp_queue,
     run_meta.probe()
     run_meta.write()
 
+    current_version = wandb.__version__
+    update.check_available(current_version)
+
     if use_redirect:
         pass
     else:
