@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
 import os
-from grpc_tools import protoc
+from grpc_tools import protoc  # type: ignore
 
 os.chdir("../..")
 protoc.main((
     '',
-    '-I', 'wandb/vendor/protobuf/src',
+    '-I', 'vendor/protobuf/src',
     '-I', '.',
     '--python_out=.',
     'wandb/proto/wandb_internal.proto',
